@@ -12,8 +12,8 @@ import copy
 path = os.path.abspath(os.path.dirname(__file__))
 sys.path.append(path)
 
-from opensnitch import ui_pb2
-from opensnitch import ui_pb2_grpc
+import opensnitch.proto as proto
+ui_pb2, ui_pb2_grpc = proto.import_()
 
 from opensnitch.dialogs.prompt import PromptDialog
 from opensnitch.dialogs.stats import StatsDialog
@@ -45,7 +45,7 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         super(UIService, self).__init__()
 
 
-        self.MENU_ENTRY_STATS = QtCore.QCoreApplication.translate("contextual_menu", "Statistics")
+        self.MENU_ENTRY_STATS = QtCore.QCoreApplication.translate("contextual_menu", "Open main window")
         self.MENU_ENTRY_FW_ENABLE = QtCore.QCoreApplication.translate("contextual_menu", "Enable")
         self.MENU_ENTRY_FW_DISABLE = QtCore.QCoreApplication.translate("contextual_menu", "Disable")
         self.MENU_ENTRY_HELP = QtCore.QCoreApplication.translate("contextual_menu", "Help")
@@ -61,9 +61,11 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         self._cfg = Config.init()
         self._db = Database.instance()
         db_file=self._cfg.getSettings(self._cfg.DEFAULT_DB_FILE_KEY)
+        db_jrnl_wal=self._cfg.getBool(Config.DEFAULT_DB_JRNL_WAL)
         db_status, db_error = self._db.initialize(
             dbtype=self._cfg.getInt(self._cfg.DEFAULT_DB_TYPE_KEY),
-            dbfile=db_file
+            dbfile=db_file,
+            dbjrnl_wal=db_jrnl_wal
         )
         if db_status is False:
             Message.ok(
@@ -413,7 +415,7 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         elif self._cfg.getBool(Config.DEFAULT_DB_PURGE_OLDEST) == False and self._cleaner != None:
             self._stop_db_cleaner()
 
-        theme_idx, theme_name = self._themes.get_saved_theme()
+        theme_idx, theme_name, theme_density = self._themes.get_saved_theme()
         if theme_idx > 0:
             self._themes.load_theme(self._app)
 
@@ -653,10 +655,12 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         _default_action = self._cfg.getInt(self._cfg.DEFAULT_ACTION_KEY)
         try:
             temp_cfg = json.loads(newconf.config)
-            if _default_action == Config.ACTION_DENY_IDX:
-                temp_cfg['DefaultAction'] = Config.ACTION_DENY
-            else:
+            if _default_action == Config.ACTION_ALLOW_IDX:
                 temp_cfg['DefaultAction'] = Config.ACTION_ALLOW
+            else:
+                temp_cfg['DefaultAction'] = Config.ACTION_DENY
+
+            print("Setting daemon DefaultAction to:", temp_cfg['DefaultAction'])
 
             newconf.config = json.dumps(temp_cfg)
         except Exception as e:
@@ -692,6 +696,10 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
                                  rule.operator.data,
                                  str(datetime.fromtimestamp(rule.created).strftime("%Y-%m-%d %H:%M:%S"))
                                  )
+            if rule.operator.type == Config.RULE_TYPE_LIST:
+                # reset list operator data before sending it back to the
+                # daemon.
+                rule.operator.data = ""
 
         elif kwargs['action'] == self.DELETE_RULE:
             self._db.delete_rule(kwargs['name'], kwargs['addr'])
@@ -699,6 +707,11 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
         elif kwargs['action'] == self.NODE_DELETE:
             self._delete_node(kwargs['peer'])
 
+    def OpenWindow(self):
+        self._stats_dialog.show()
+
+    def close(self):
+        self._on_close()
 
     def PostAlert(self, alert, context):
         proto, addr = self._get_peer(context.peer())
@@ -738,8 +751,9 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
 
         # TODO: allow connections originated from ourselves: os.getpid() == request.pid)
         self._asking = True
-        proto, addr = self._get_peer(context.peer())
-        rule, timeout_triggered = self._prompt_dialog.promptUser(request, self._is_local_request(proto, addr), context.peer())
+        peer = context.peer()
+        proto, addr = self._get_peer(peer)
+        rule, timeout_triggered = self._prompt_dialog.promptUser(request, self._is_local_request(proto, addr), peer)
         self._last_ping = datetime.now()
         self._asking = False
         if rule == None:
@@ -764,14 +778,14 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
                 {
                     'action': self.DELETE_RULE,
                     'name': rule.name,
-                    'addr': context.peer()
+                    'addr': peer
                 }
             )
         else:
             self._node_actions_trigger.emit(
                 {
                     'action': self.ADD_RULE,
-                    'peer': context.peer(),
+                    'peer': peer,
                     'rule': rule
                 }
             )
@@ -891,6 +905,3 @@ class UIService(ui_pb2_grpc.UIServicer, QtWidgets.QGraphicsObject):
                 context.cancel()
 
         return node_iter
-
-    def OpenWindow(self):
-        self._stats_dialog.show()
